feast.core package — Feast 0.3.2 documentation

# feast.core package

## Submodules

## feast.core.CoreService_pb2 module

class `feast.core.CoreService_pb2.` `ApplyFeatureSetRequest`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  `feature_set`

    Field feast.core.ApplyFeatureSetRequest.feature_set

class `feast.core.CoreService_pb2.` `ApplyFeatureSetResponse`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `CREATED` = 1
  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  `ERROR` = 2
  `NO_CHANGE` = 0
  `Status` = <google.protobuf.internal.enum_type_wrapper.EnumTypeWrapper object>
  `feature_set`

    Field feast.core.ApplyFeatureSetResponse.feature_set

  `status`

    Field feast.core.ApplyFeatureSetResponse.status

class `feast.core.CoreService_pb2.` `GetFeastCoreVersionRequest`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>

class `feast.core.CoreService_pb2.` `GetFeastCoreVersionResponse`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  `version`

    Field feast.core.GetFeastCoreVersionResponse.version

class `feast.core.CoreService_pb2.` `GetFeatureSetRequest`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  `name`

    Field feast.core.GetFeatureSetRequest.name

  `version`

    Field feast.core.GetFeatureSetRequest.version

class `feast.core.CoreService_pb2.` `GetFeatureSetResponse`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  `feature_set`

    Field feast.core.GetFeatureSetResponse.feature_set

class `feast.core.CoreService_pb2.` `ListFeatureSetsRequest`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  class `Filter`

    Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

    `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
    `feature_set_name`

      Field feast.core.ListFeatureSetsRequest.Filter.feature_set_name

    `feature_set_version`

      Field feast.core.ListFeatureSetsRequest.Filter.feature_set_version

  `filter`

    Field feast.core.ListFeatureSetsRequest.filter

class `feast.core.CoreService_pb2.` `ListFeatureSetsResponse`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  `feature_sets`

    Field feast.core.ListFeatureSetsResponse.feature_sets

class `feast.core.CoreService_pb2.` `ListStoresRequest`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  class `Filter`

    Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

    `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
    `name`

      Field feast.core.ListStoresRequest.Filter.name

  `filter`

    Field feast.core.ListStoresRequest.filter

class `feast.core.CoreService_pb2.` `ListStoresResponse`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  `store`

    Field feast.core.ListStoresResponse.store

class `feast.core.CoreService_pb2.` `UpdateStoreRequest`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  `store`

    Field feast.core.UpdateStoreRequest.store

class `feast.core.CoreService_pb2.` `UpdateStoreResponse`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  `NO_CHANGE` = 0
  `Status` = <google.protobuf.internal.enum_type_wrapper.EnumTypeWrapper object>
  `UPDATED` = 1
  `status`

    Field feast.core.UpdateStoreResponse.status

  `store`

    Field feast.core.UpdateStoreResponse.store

## feast.core.CoreService_pb2_grpc module

class `feast.core.CoreService_pb2_grpc.` `CoreServiceServicer`

  Bases: `object`

  `ApplyFeatureSet`(request, context)

    Create or update and existing feature set.

    This function is idempotent - it will not create a new feature set if schema does not change. If an existing feature set is updated, core will advance the version number, which will be returned in response.

  `GetFeastCoreVersion`(request, context)

    Retrieve version information about this Feast deployment

  `GetFeatureSet`(request, context)

    Returns a specific feature set

  `ListFeatureSets`(request, context)

    Retrieve feature set details given a filter.

    Returns all feature sets matching that filter. If none are found, an empty list will be returned. If no filter is provided in the request, the response will contain all the feature sets currently stored in the registry.

  `ListStores`(request, context)

    Retrieve store details given a filter.

    Returns all stores matching that filter. If none are found, an empty list will be returned. If no filter is provided in the request, the response will contain all the stores currently stored in the registry.

  `UpdateStore`(request, context)

    Updates core with the configuration of the store.

    If the changes are valid, core will return the given store configuration in response, and start or update the necessary feature population jobs for the updated store.

class `feast.core.CoreService_pb2_grpc.` `CoreServiceStub`(channel)

  Bases: `object`

`feast.core.CoreService_pb2_grpc.` `add_CoreServiceServicer_to_server`(servicer, server)

## feast.core.FeatureSet_pb2 module

class `feast.core.FeatureSet_pb2.` `EntitySpec`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  `name`

    Field feast.core.EntitySpec.name

  `value_type`

    Field feast.core.EntitySpec.value_type

class `feast.core.FeatureSet_pb2.` `FeatureSetSpec`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  `entities`

    Field feast.core.FeatureSetSpec.entities

  `features`

    Field feast.core.FeatureSetSpec.features

  `max_age`

    Field feast.core.FeatureSetSpec.max_age

  `name`

    Field feast.core.FeatureSetSpec.name

  `source`

    Field feast.core.FeatureSetSpec.source

  `version`

    Field feast.core.FeatureSetSpec.version

class `feast.core.FeatureSet_pb2.` `FeatureSpec`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  `name`

    Field feast.core.FeatureSpec.name

  `value_type`

    Field feast.core.FeatureSpec.value_type

## feast.core.FeatureSet_pb2_grpc module

## feast.core.Source_pb2 module

class `feast.core.Source_pb2.` `KafkaSourceConfig`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  `bootstrap_servers`

    Field feast.core.KafkaSourceConfig.bootstrap_servers

  `topic`

    Field feast.core.KafkaSourceConfig.topic

class `feast.core.Source_pb2.` `Source`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  `kafka_source_config`

    Field feast.core.Source.kafka_source_config

  `type`

    Field feast.core.Source.type

## feast.core.Source_pb2_grpc module

## feast.core.Store_pb2 module

class `feast.core.Store_pb2.` `Store`

  Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

  `BIGQUERY` = 2
  class `BigQueryConfig`

    Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

    `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
    `dataset_id`

      Field feast.core.Store.BigQueryConfig.dataset_id

    `project_id`

      Field feast.core.Store.BigQueryConfig.project_id

  `CASSANDRA` = 3
  class `CassandraConfig`

    Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

    `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
    `host`

      Field feast.core.Store.CassandraConfig.host

    `port`

      Field feast.core.Store.CassandraConfig.port

  `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
  `INVALID` = 0
  `REDIS` = 1
  class `RedisConfig`

    Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

    `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
    `host`

      Field feast.core.Store.RedisConfig.host

    `port`

      Field feast.core.Store.RedisConfig.port

  `StoreType` = <google.protobuf.internal.enum_type_wrapper.EnumTypeWrapper object>
  class `Subscription`

    Bases: `google.protobuf.pyext._message.CMessage`, `google.protobuf.message.Message`

    `DESCRIPTOR` = <google.protobuf.pyext._message.MessageDescriptor object>
    `name`

      Field feast.core.Store.Subscription.name

    `version`

      Field feast.core.Store.Subscription.version

  `bigquery_config`

    Field feast.core.Store.bigquery_config

  `cassandra_config`

    Field feast.core.Store.cassandra_config

  `name`

    Field feast.core.Store.name

  `redis_config`

    Field feast.core.Store.redis_config

  `subscriptions`

    Field feast.core.Store.subscriptions

  `type`

    Field feast.core.Store.type

## feast.core.Store_pb2_grpc module

## Module contents